@@ -3,7 +3,7 @@ from django.template import RequestContext, Context, loader
 from django.template.defaultfilters import slugify
 from django.utils.http import urlquote
 
-class SearchManager:
+class SearchManager(object):
     """
     Générateur de recherche avancée.
     
